@@ -1,12 +1,11 @@
-from commmons import html
-from commmons.url import get_host_url
+from commmons import html_from_url, get_host_url
 
 from vripper.model.vimage import VImage
 from vripper.model.vthread import VThread
 
 
 def nlegs_init(url: str):
-    root = html.from_url(url)
+    root = html_from_url(url)
 
     thread = VThread(
         id=url.split('/')[-1].split('.')[0],
