@@ -1,11 +1,11 @@
-from commmons import html
+from commmons import html_from_url
 
 from vripper.model.vimage import VImage
 from vripper.model.vthread import VThread
 
 
 def sbgx_init(url):
-    root = html.from_url(url)
+    root = html_from_url(url)
 
     content = root.xpath("//div[contains(@class, 'post-body') and contains(@class, 'entry-content')]")[0]
 
