@@ -1,4 +1,5 @@
 from commmons import html_from_url, md5
+from pydash import head
 
 from vripper.model.vimage import VImage
 from vripper.model.vthread import VThread
@@ -15,10 +16,14 @@ def v2ph_init(url):
 
     # id may contain filesystem-unsafe characters such as the question mark
     hashed_id = md5(url.split("/album/")[-1].split(".")[0].split("?")[0])
+    title = "v2ph thread"
+    h1 = head(root.xpath("//h1[contains(@class, 'text-center')]"))
+    if h1:
+        title = h1.text
 
     thread = VThread(
         id=hashed_id,
-        title=root.xpath("//h1[contains(@class, 'text-center')]")[0].text,
+        title=title,
         with_empty_post=True
     )
 
