@@ -1,4 +1,4 @@
-from commmons.url import get_host_url
+from commmons import get_host_url
 
 from vripper.parser._common import parse
 from vripper.parser._def import parser
